pub fn shutdown_browser() -> Result<(), Error>Expand description
Shutdown and kill any spawned Chrome used by Mermaid rendering. This ensures the process doesn’t keep child processes or background threads alive which can prevent the main program from exiting when its output is piped.